
#ifndef LIBRARY_KDKACCTSEC_H
#define LIBRARY_KDKACCTSEC_H

enum crypt_type
{
md5=1,
bigcrypt=2,
sha256=3,
sha512=4,
blowfish=5,
sm3=6
};

typedef struct _kysec_pswcheck {
  
    int remember;                           // 是否启用历史密码记录检测,0表示不开启
   
    int passwd_limit_time;                  // 密码有效期,单位天，0表示不限制
    int passwd_warn_time;                   // 密码过期警告时间,单位天，0表示不告警

    int minlen;                             // 密码最小长度
    int minclass;                           // 密码至少包含字符种类
    enum crypt_type crypt_t;              //密码加密算法
                 
}kysec_pswcheck;

typedef struct {
    char *user;
    char *uid;
    int count;
    char *old_passwords;
} opwd;



/**
 * @brief 获得密码强度检查模块开启关闭状态
 * @param 
 * @return 1 开启
 *         0 关闭
 *         -1 异常
 */
int kdk_acctsec_get_pswche_status();

/**
 * @brief 从各配置文件中获取密码强度设置项的值
 * @param pswcheck 密码强度检查配置项信息结构体
 * @return 0 成功
 *         -1 获取配置文件异常
 *        
 * 
 */
int kdk_acctsec_get_pswche_conf(kysec_pswcheck *pswcheck);

/**
 * @brief 将需修改的配置项更新到各个配置文件中
 * @param pswcheck 密码强度检查配置项信息结构体
 * @return 0 成功
 *        -1 更新配置文件异常
 *         
 *                 
 */
int kdk_acctsec_update_pswche_conf(kysec_pswcheck *pswcheck);

/**
 * @brief 更改密码强度检测模块的开启关闭状态
 * @param  status 1：开启模块    0：关闭模块
 * @return 0 成功
 *         -1 失败         
 */
int kdk_acctsec_update_pswche_status(int status);


/**
 * @brief 获得账户锁定模块开启关闭状态
 * @param 
 * @return 1 开启
 *         0 关闭
 *         -1 异常
 */
int kdk_acctsec_get_acctlock_status();

/**
 * @brief 根据配置文件获得账户锁定设置项的值
 * @param  *deny 存放从配置文件获得的账户锁定阈值
 *          *unlock_time 存放从配置文件获得的账户锁定时间
 * @return 0 成功
 *         -1 失败
 *         
 */
int kdk_acctsec_get_acctlock_conf( int *deny, int *unlock_time );

/**
 * @brief 根据配置文件获得账户锁定设置项的值
 * @param  *deny 将更新到配置文件的账户锁定阈值
 *          *unlock_time 将更新到配置文件的账户锁定时间
 * @return 0 成功
 *         -1 失败
 *         
 */
int kdk_acctsec_update_acctlock_conf(int deny, int unlock_time);

/**
 * @brief 更新账户锁定模块开启关闭状态
 * @param status 1：开启模块    0：关闭模块
 * @return 0 成功
 *         1 失败
 *         
 */
int kdk_acctsec_update_acctlock_status(int status);


/*
* @brief  密码历史检测
* @param newpass 新密码字符串
* @param user 用户名
* @return  0 新密码是历史记录限制次数内使用过得密码
*          -1 新密码不是是历史记录限制次数内使用过得密码
*/
int kdk_acctsec_check_pwhistory(const char *newpass, const char *user);


#endif
